@@ -19,7 +19,7 @@
 
 package demo.colocated.server;
 
-import javax.xml.ws.Endpoint;
+import jakarta.xml.ws.Endpoint;
 
 public class Server {
 
