@@ -18,9 +18,8 @@
  */
 package org.apache.cxf.systest.microprofile.rest.client;
 
-import javax.ws.rs.GET;
-import javax.ws.rs.Path;
-
+import jakarta.ws.rs.GET;
+import jakarta.ws.rs.Path;
 import org.eclipse.microprofile.rest.client.annotation.RegisterClientHeaders;
 
 @Path("/remote")
