@@ -19,7 +19,7 @@
 
 package org.apache.cxf.systest.transform.feature;
 
-import javax.jws.WebService;
+import jakarta.jws.WebService;
 
 @WebService
 public interface Echo {
